Crate buf

Crate buf 

Utilities for working with buffers.

Completion APIs require passing ownership of buffers to the runtime. The crate defines IoBuf and IoBufMut traits which are implemented by buffer types that respect the safety contract.

Modules

arrayvec
arrayvec provides the types ArrayVec and ArrayString: array-backed vector and string types, which store their contents inline.
bumpalo
bumpalo
bytes
Provides abstractions for working with bytes.

Macros

buf_try
A helper macro to imitate the behavior of try trait ?.

Structs

BufResult
A specialized Result type for operations with buffers.
IoBuffer
An unsafe, 'static, partially initialized, and mutable buffer.
IoSlice
An unsafe, 'static, initialized, and immutable slice of bytes to interact with system API.
IoSliceMut
An unsafe, 'static, maybe uninitialized, and mutable slice of bytes to interact with system API.
Slice
An owned view into a contiguous sequence of bytes.
Uninit
A Slice that only exposes uninitialized bytes.
VectoredBufIter
An owned iterator over a vectored buffer.
VectoredSlice
An owned view of a vectored buffer.
VectoredSliceMut
An owned view of a vectored buffer.

Traits

IntoInner
Trait to get the inner buffer of an operation or a result.
IoBuf
A trait for buffers.
IoBufMut
A mutable compio compatible buffer.
IoVectoredBuf
A trait for vectored buffers.
IoVectoredBufMut
A trait for mutable vectored buffers.
SetBufInit
A helper trait for set_len like methods.