Module error

Module error 

Available on crate features quic and h3 only.
This module contains the error handling logic and types for the h3 crate.

Modules

connection_error_creatorsi-implement-a-third-party-backend-and-opt-into-breaking-changes
functions to create the error structs
internal_errori-implement-a-third-party-backend-and-opt-into-breaking-changes
This module contains the internal error type, which is used to represent errors, which have not yet affected the connection state

Structs

Code
An HTTP/3 “application error code”.

Enums

ConnectionError
This enum represents the closure of a connection because of an a closed quic connection This can be either from this endpoint because of a violation of the protocol or from the remote endpoint
LocalError
This enum represents a local error
StreamError
This enum represents a stream error