submit_with_flags

Function submit_with_flags 

pub async fn submit_with_flags<T>(op: T) -> (BufResult<usize, T>, u32)
where T: OpCode + 'static,
Available on crate feature runtime only.
Submit an operation to the current runtime, and return a future for it with flags.

Panics

This method doesn’t create runtime. It tries to obtain the current runtime by Runtime::with_current.