pub struct RuntimeBuilder { /* private fields */ }Available on crate feature
runtime only.Expand description
Builder for Runtime.
Implementations
Sourceimpl RuntimeBuilder
impl RuntimeBuilder
Sourcepub fn new() -> RuntimeBuilder
pub fn new() -> RuntimeBuilder
Create the builder with default config.
Sourcepub fn with_proactor(&mut self, builder: ProactorBuilder) -> &mut RuntimeBuilder
pub fn with_proactor(&mut self, builder: ProactorBuilder) -> &mut RuntimeBuilder
Replace proactor builder.
Sourcepub fn thread_affinity(&mut self, cpus: HashSet<usize>) -> &mut RuntimeBuilder
pub fn thread_affinity(&mut self, cpus: HashSet<usize>) -> &mut RuntimeBuilder
Sets the thread affinity for the runtime.
Sourcepub fn event_interval(&mut self, val: usize) -> &mut RuntimeBuilder
pub fn event_interval(&mut self, val: usize) -> &mut RuntimeBuilder
Sets the number of scheduler ticks after which the scheduler will poll for external events (timers, I/O, and so on).
A scheduler “tick” roughly corresponds to one poll invocation on a task.