TicketSwitcher

Struct TicketSwitcher 

pub struct TicketSwitcher { /* private fields */ }
Available on crate feature tls and (crate features std or hashbrown) only.
A ticketer that has a ‘current’ sub-ticketer and a single ‘previous’ ticketer. It creates a new ticketer every so often, demoting the current ticketer.

Implementations

Source

impl TicketSwitcher

pub fn new( lifetime: u32, generator: fn() -> Result<Box<dyn ProducesTickets>, GetRandomFailed>, ) -> Result<TicketSwitcher, Error>

👎Deprecated: use TicketRotator instead
Available on crate feature std only.

Creates a new TicketSwitcher, which rotates through sub-ticketers based on the passage of time.

lifetime is in seconds, and is how long the current ticketer is used to generate new tickets. Tickets are accepted for no longer than twice this duration. generator produces a new ProducesTickets implementation.